==> net.bluemind.p2.we.adminconsole-4.9.3879.zip: net/bluemind/mailbox/api/gwt/js/JsSimpleShardStats.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.mailbox.api.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsSimpleShardStats extends JavaScriptObject {

	protected JsSimpleShardStats() {}

	public final native String getIndexName()
	/*-{
	return this["indexName"];
	}-*/;

	public final native void setIndexName(String indexName)
	/*-{
       this["indexName"] = indexName;
	}-*/;

	public final native com.google.gwt.core.client.JsArrayString getMailboxes()
	/*-{
	return this["mailboxes"];
	}-*/;

	public final native void setMailboxes(com.google.gwt.core.client.JsArrayString mailboxes)
	/*-{
       this["mailboxes"] = mailboxes;
	}-*/;

	public final native java.lang.Long getDocCount()
	/*-{
	return this["docCount"];
	}-*/;

	public final native void setDocCount(java.lang.Long docCount)
	/*-{
       this["docCount"] = docCount;
	}-*/;

	public final native java.lang.Long getDeletedCount()
	/*-{
	return this["deletedCount"];
	}-*/;

	public final native void setDeletedCount(java.lang.Long deletedCount)
	/*-{
       this["deletedCount"] = deletedCount;
	}-*/;

	public final native java.lang.Long getExternalRefreshCount()
	/*-{
	return this["externalRefreshCount"];
	}-*/;

	public final native void setExternalRefreshCount(java.lang.Long externalRefreshCount)
	/*-{
       this["externalRefreshCount"] = externalRefreshCount;
	}-*/;

	public final native java.lang.Long getExternalRefreshDuration()
	/*-{
	return this["externalRefreshDuration"];
	}-*/;

	public final native void setExternalRefreshDuration(java.lang.Long externalRefreshDuration)
	/*-{
       this["externalRefreshDuration"] = externalRefreshDuration;
	}-*/;

	public final native java.lang.Long getSize()
	/*-{
	return this["size"];
	}-*/;

	public final native void setSize(java.lang.Long size)
	/*-{
       this["size"] = size;
	}-*/;

	public static native  JsSimpleShardStats create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}

==> net.bluemind.p2.we.adminconsole-5.5.3184.zip: net/bluemind/mailbox/api/gwt/js/JsSimpleShardStats.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */

package net.bluemind.mailbox.api.gwt.js;

import com.google.gwt.core.client.JavaScriptObject;

public class JsSimpleShardStats extends JavaScriptObject {

	protected JsSimpleShardStats() {}

	public final native String getIndexName()
	/*-{
	return this["indexName"];
	}-*/;

	public final native void setIndexName(String indexName)
	/*-{
       this["indexName"] = indexName;
	}-*/;

	public final native com.google.gwt.core.client.JsArrayString getMailboxes()
	/*-{
	return this["mailboxes"];
	}-*/;

	public final native void setMailboxes(com.google.gwt.core.client.JsArrayString mailboxes)
	/*-{
       this["mailboxes"] = mailboxes;
	}-*/;

	public final native com.google.gwt.core.client.JsArrayString getAliases()
	/*-{
	return this["aliases"];
	}-*/;

	public final native void setAliases(com.google.gwt.core.client.JsArrayString aliases)
	/*-{
       this["aliases"] = aliases;
	}-*/;

	public final native java.lang.Long getDocCount()
	/*-{
	return this["docCount"];
	}-*/;

	public final native void setDocCount(java.lang.Long docCount)
	/*-{
       this["docCount"] = docCount;
	}-*/;

	public final native java.lang.Long getDeletedCount()
	/*-{
	return this["deletedCount"];
	}-*/;

	public final native void setDeletedCount(java.lang.Long deletedCount)
	/*-{
       this["deletedCount"] = deletedCount;
	}-*/;

	public final native java.lang.Long getExternalRefreshCount()
	/*-{
	return this["externalRefreshCount"];
	}-*/;

	public final native void setExternalRefreshCount(java.lang.Long externalRefreshCount)
	/*-{
       this["externalRefreshCount"] = externalRefreshCount;
	}-*/;

	public final native java.lang.Long getExternalRefreshDuration()
	/*-{
	return this["externalRefreshDuration"];
	}-*/;

	public final native void setExternalRefreshDuration(java.lang.Long externalRefreshDuration)
	/*-{
       this["externalRefreshDuration"] = externalRefreshDuration;
	}-*/;

	public final native java.lang.Long getSize()
	/*-{
	return this["size"];
	}-*/;

	public final native void setSize(java.lang.Long size)
	/*-{
       this["size"] = size;
	}-*/;

	public static native  JsSimpleShardStats create()
	/*-{
       var ret = {};
       return ret;
	}-*/;

}
